# Pandocster

Конвейер сборки документации из исходных файлов в формате Markdown.
За основу был взят подход вот из [этой статьи](https://habr.com/ru/articles/987982/),
но тамошнее решение было, с одной стороны, сильно сложное, а, с другой, не решало задачу
"просто собрать документ со структурой, повторяющей структур каталогов исходных файлов".

Главный драйвер создания `pandocster` был в том, чтобы получить простой инструмент,
который однажды установил и потом что угодно можешь собрать и сверстать одной командой.
